local state = {
  floating = {
    buf = -1,
    win = -1,
  }
}

local function create_floating_window(ops)
  ops = ops or {}
  local width = ops.width or math.floor(vim.o.columns * 0.8)
  local height = ops.height or math.floor(vim.o.lines * 0.8)

  local buf
  if vim.api.nvim_buf_is_valid(state.floating.buf) then
    buf = state.floating.buf
    vim.cmd("startinsert")
  else
    buf = vim.api.nvim_create_buf(false, true)
  end

  local win = vim.api.nvim_open_win(buf, true, {
    relative = "editor",
    style = "minimal",
    border = "rounded",
    width = width,
    height = height,
    col = math.floor((vim.o.columns - width) / 2),
    row = math.floor((vim.o.lines - height) / 2),
  })
  return { buf = buf, win = win }
end

local function toggle_terminal()
  if vim.api.nvim_win_is_valid(state.floating.win) then
    vim.api.nvim_win_hide(state.floating.win)
  else
    state.floating = create_floating_window { buf = state.floating.buf }
    if vim.bo[state.floating.buf].buftype ~= "terminal" then
      vim.cmd.terminal()
      vim.cmd("startinsert")
    end
  end
end

return toggle_terminal
